########################################################################################################################
# Description: Init file for SPAT                                                               #
# Author: Jasmine-Arabella Post                                                                                        #
# Date Started: 20230209                                                                                               #
########################################################################################################################

print("this is my init file")

from .API_Call import API
import  atr









# End of File
#
